public class ZAEHLER_ZYKLISCH
{
    int Zaehlerstand;
    int Max;

    public ZAEHLER_ZYKLISCH(int max)
    {
        Zaehlerstand = 0;
        Max = max;
    }

    public void Set_Null()
    {
        Zaehlerstand = 0;
    }
    
    public void Zaehlen()
    {
        if (Zaehlerstand == Max) {Set_Null();} 
                            else {Zaehlerstand = Zaehlerstand +1;};
        
    }
    
    public int Get_Zaehlerstand()
    {
        return Zaehlerstand;
    }        
}
